Документация по django-ulogin — Документация django-ulogin 0.3.0

# Документация по django-ulogin

https://github.com/marazmiki/django-ulogin

## Описание

django-ulogin — подключаемое универсальное django-приложение для социальной аутентификации пользователей с помощью внешнего интернет-сервиса uLogin

Внимание

Создатели приложения никак не связаны с интернет-сервисом uLogin, поэтому все вопросы, касающиеся непосредственно работы сервиса, а не этого приложения, просьба отправлять на team@ulogin.ru.

## Содержание

- Системные требования
- Установка
- Конфигурация проекта
- Использование
  - Быстрый старт
- Для опытных пользователей
  - Тонкая настройка
  - Схемы
  - Сигналы
  - Создание нестандартной модели пользователя
- Хотите помочь с django-ulogin?
  - Сообщайте об ошибках
  - Пишите код
  - Рекомендации для написания кода
- История изменений
  - 0.3x
  - 0.2x
  - 0.1x
- Авторы
- Лицензия

# Оглавления и индексы

- Алфавитный указатель
- Поиск